#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# TIConvert v0.4.1
# By Michael Lee
# Released July 16th, 2011
#
# Please see /readme_TIConvert.txt
# Licensed under the MIT License (see /license_TIConvert.txt)
#
# Written in Python 2.7
#

import os
import argparse

import meta


class CommandIO():
    def __init__(self):
        """Creates the command line parser."""
        self._create_parser()
        self._options = {}
        return

    def _create_parser(self):
        """Adds options for the parser."""
        ## Creating the parser
        self._parser = argparse.ArgumentParser(description=meta.description,
                                               add_help=True,
                                               prog=meta.program_name)
        ## Positional (mandatory) arguments
        self._parser.add_argument("input_path",
                                  nargs='?',
                                  type=str,
                                  help="The path to the file to compile or" \
                                       "decompile.")
        ## Optional arguments
        self._parser.add_argument("-v", "--version",
                                  action="version",
                                  version=meta.version,
                                  help="Display the version and release date.")
        self._parser.add_argument("-c", "--colons", "--colon",
                                  action="store_const",
                                  const=True,
                                  default=False,
                                  help="Adds colons to the start of each line.",
                                  dest="colons")
        self._parser.add_argument("-n", "--name", "--program_name",
                                  action="store",
                                  nargs="?",
                                  const=None,
                                  default=None,
                                  help="The name you want your 8xp to have.",
                                  dest="program_name")
        self._parser.add_argument("-t", "--tabs", "--tab", "--tab_length",
                                  action="store",
                                  nargs="?",
                                  const=4,
                                  default=0,
                                  type=int,
                                  help="The following number will be the " \
                                       "number of spaces per each indent.  " \
                                       "Defaults to 4 spaces.",
                                  dest="tab_length")
        self._parser.add_argument("-u", "--unicode", "--utf8", "--utf_8",
                                  action="store_const",
                                  const="utf8",
                                  default="ascii",
                                  help="If present, makes any .txt output" \
                                       "use special characters (-> turns to "\
                                       "→, for example).",
                                  dest="encoding")
        return

    def parse(self):
        """Runs the command line parser.

        Arguments:
         - None

        Returns:
         - A dictionary of name-key pairs:
           {"colons"       : bool,
            "tab_length"   : int,
            "input_path"   : str,
            "output_path"  : str,
            "program_name" : str or None}
        """
        options = self._parser.parse_args()

        if not(options.input_path):
            self._parser.parse_args(["--help"])
        
        self._options["colons"] = options.colons
        self._options["tab_length"] = options.tab_length
        self._options["input_path"] = options.input_path
        self._options["output_path"] = self._make_output_name(
                                           options.input_path)
        self._options["program_name"] = options.program_name
        self._options["encoding"] = options.encoding
        return self._options

    def _make_output_name(self, input_path):
        """Switches the extentions"""
        mark = input_path.rfind(os.extsep)+1    # Just in case 
        extention = input_path[mark:]
        if extention == "8xp":
            return input_path[:mark] + "txt"
        elif extention == "txt":
            return input_path[:mark] + "8xp"
        return

